==> messagelib-22.11.80.tar.xz: messagelib-22.11.80/messagecomposer/src/snippet/convertsnippetvariablesutil.cpp <==
/*
   SPDX-FileCopyrightText: 2019-2022 Laurent Montel <montel@kde.org>

   SPDX-License-Identifier: LGPL-2.0-or-later
*/

#include "convertsnippetvariablesutil.h"

#include <QDateTime>
#include <QLocale>

QString MessageComposer::ConvertSnippetVariablesUtil::snippetVariableFromEnum(MessageComposer::ConvertSnippetVariablesUtil::VariableType type)
{
    switch (type) {
    case CcAddr:
        return QStringLiteral("%CCADDR");
    case CcLname:
        return QStringLiteral("%CCLNAME");
    case CcFname:
        return QStringLiteral("%CCFNAME");
    case CcName:
        return QStringLiteral("%CCNAME");
    case BccAddr:
        return QStringLiteral("%BCCADDR");
    case BccLname:
        return QStringLiteral("%BCCLNAME");
    case BccFname:
        return QStringLiteral("%BCCFNAME");
    case BccName:
        return QStringLiteral("%BCCNAME");
    case FullSubject:
        return QStringLiteral("%FULLSUBJECT");
    case ToAddr:
        return QStringLiteral("%TOADDR");
    case ToFname:
        return QStringLiteral("%TOFNAME");
    case ToLname:
        return QStringLiteral("%TOLNAME");
    case ToName:
        return QStringLiteral("%TONAME");
    case FromAddr:
        return QStringLiteral("%FROMADDR");
    case FromLname:
        return QStringLiteral("%FROMLNAME");
    case FromFname:
        return QStringLiteral("%FROMFNAME");
    case FromName:
        return QStringLiteral("%FROMNAME");
    case Dow:
        return QStringLiteral("%DOW");
    case Date:
        return QStringLiteral("%DATE");
    case ShortDate:
        return QStringLiteral("%SHORTDATE");
    case Time:
        return QStringLiteral("%TIME");
    case TimeLong:
        return QStringLiteral("%TIMELONG");
    case AttachmentCount:
        return QStringLiteral("%ATTACHMENTCOUNT");
    case AttachmentName:
        return QStringLiteral("%ATTACHMENTNAMES");
    case AttachmentFilenames:
        return QStringLiteral("%ATTACHMENTFILENAMES");
    case AttachmentNamesAndSizes:
        return QStringLiteral("%ATTACHMENTNAMESANDSIZES");
    case Year:
        return QStringLiteral("%YEAR");
    case LastYear:
        return QStringLiteral("%LASTYEAR");
    case NextYear:
        return QStringLiteral("%NEXTYEAR");
    case MonthNumber:
        return QStringLiteral("%MONTHNUMBER"); // 1-12
    case DayOfMonth:
        return QStringLiteral("%DAYOFMONTH"); // 1-31
    case WeekNumber:
        return QStringLiteral("%WEEKNUMBER"); // 1-52
    case MonthNameShort:
        return QStringLiteral("%MONTHNAMESHORT"); //(Jan-Dec)
    case MonthNameLong:
        return QStringLiteral("%MONTHNAMELONG"); //(January-December)
    case DayOfWeek:
        return QStringLiteral("%DAYOFWEEK"); //(1-7)
    case DayOfWeekNameShort:
        return QStringLiteral("%DAYOFWEEKNAMESHORT"); //(Mon-Sun)
    case DayOfWeekNameLong:
        return QStringLiteral("%DAYOFWEEKNAMELONG"); //(Monday-Sunday)
    case YearLastMonth:
        return QStringLiteral("%YEARLASTMONTH"); // january 2020 will how 2019-12
    case LastMonthNameLong:
        return QStringLiteral("%LASTMONTHNAMELONG");
    }
    return {};
}

QString MessageComposer::ConvertSnippetVariablesUtil::shortDate()
{
    QLocale locale;
    return locale.toString(QDate::currentDate(), QLocale::ShortFormat);
}

QString MessageComposer::ConvertSnippetVariablesUtil::longDate()
{
    QLocale locale;
    return locale.toString(QDate::currentDate(), QLocale::LongFormat);
}

QString MessageComposer::ConvertSnippetVariablesUtil::shortTime()
{
    QLocale locale;
    return locale.toString(QTime::currentTime(), QLocale::ShortFormat);
}

QString MessageComposer::ConvertSnippetVariablesUtil::longTime()
{
    QLocale locale;
    return locale.toString(QTime::currentTime(), QLocale::LongFormat);
}

QString MessageComposer::ConvertSnippetVariablesUtil::insertDayOfWeek()
{
    const QDateTime date = QDateTime::currentDateTime().toLocalTime();
    const QString str = QLocale().dayName(date.date().dayOfWeek(), QLocale::LongFormat);
    return str;
}

QString MessageComposer::ConvertSnippetVariablesUtil::lastYear()
{
    const QDate date = QDate::currentDate();
    return QString::number(date.year() - 1);
}

QString MessageComposer::ConvertSnippetVariablesUtil::nextYear()
{
    const QDate date = QDate::currentDate();
    return QString::number(date.year() + 1);
}

QString MessageComposer::ConvertSnippetVariablesUtil::monthNumber()
{
    const QDate date = QDate::currentDate();
    return QString::number(date.month());
}

QString MessageComposer::ConvertSnippetVariablesUtil::dayOfMonth()
{
    const QDate date = QDate::currentDate();
    return QString::number(date.daysInMonth());
}

QString MessageComposer::ConvertSnippetVariablesUtil::weekNumber()
{
    const QDate date = QDate::currentDate();
    return QString::number(date.weekNumber());
}

QString MessageComposer::ConvertSnippetVariablesUtil::monthNameShort()
{
    const QDate date = QDate::currentDate();
    return date.toString(QStringLiteral("MMM"));
}

QString MessageComposer::ConvertSnippetVariablesUtil::monthNameLong()
{
    const QDate date = QDate::currentDate();
    return date.toString(QStringLiteral("MMMM"));
}

QString MessageComposer::ConvertSnippetVariablesUtil::lastMonthNameLong()
{
    const QDate date = QDate::currentDate().addMonths(-1);
    return date.toString(QStringLiteral("MMMM"));
}

QString MessageComposer::ConvertSnippetVariablesUtil::dayOfWeekNameShort()
{
    const QDate date = QDate::currentDate();
    return date.toString(QStringLiteral("ddd"));
}

QString MessageComposer::ConvertSnippetVariablesUtil::dayOfWeekNameLong()
{
    const QDate date = QDate::currentDate();
    return date.toString(QStringLiteral("dddd"));
}

QString MessageComposer::ConvertSnippetVariablesUtil::yearLastMonth()
{
    const QDate date = QDate::currentDate();
    return date.toString(date.toString(QStringLiteral("yyyy-MMM")));
}

QString MessageComposer::ConvertSnippetVariablesUtil::year()
{
    const QDate date = QDate::currentDate();
    return date.toString(QString::number(date.year()));
}

QString MessageComposer::ConvertSnippetVariablesUtil::dayOfWeek()
{
    const QDate date = QDate::currentDate();
    return date.toString(QString::number(date.dayOfWeek()));
}

==> messagelib_25.07.80.orig.tar.xz: messagelib-25.07.80/messagecomposer/src/snippet/convertsnippetvariablesutil.cpp <==
/*
   SPDX-FileCopyrightText: 2019-2025 Laurent Montel <montel@kde.org>

   SPDX-License-Identifier: LGPL-2.0-or-later
*/

#include "convertsnippetvariablesutil.h"
using namespace Qt::Literals::StringLiterals;

#include <QDateTime>
#include <QLocale>

QString MessageComposer::ConvertSnippetVariablesUtil::snippetVariableFromEnum(MessageComposer::ConvertSnippetVariablesUtil::VariableType type)
{
    switch (type) {
    case CcAddr:
        return u"%CCADDR"_s;
    case CcLname:
        return u"%CCLNAME"_s;
    case CcFname:
        return u"%CCFNAME"_s;
    case CcName:
        return u"%CCNAME"_s;
    case BccAddr:
        return u"%BCCADDR"_s;
    case BccLname:
        return u"%BCCLNAME"_s;
    case BccFname:
        return u"%BCCFNAME"_s;
    case BccName:
        return u"%BCCNAME"_s;
    case FullSubject:
        return u"%FULLSUBJECT"_s;
    case ToAddr:
        return u"%TOADDR"_s;
    case ToFname:
        return u"%TOFNAME"_s;
    case ToLname:
        return u"%TOLNAME"_s;
    case ToName:
        return u"%TONAME"_s;
    case FromAddr:
        return u"%FROMADDR"_s;
    case FromLname:
        return u"%FROMLNAME"_s;
    case FromFname:
        return u"%FROMFNAME"_s;
    case FromName:
        return u"%FROMNAME"_s;
    case Dow:
        return u"%DOW"_s;
    case Date:
        return u"%DATE"_s;
    case ShortDate:
        return u"%SHORTDATE"_s;
    case Time:
        return u"%TIME"_s;
    case TimeLong:
        return u"%TIMELONG"_s;
    case AttachmentCount:
        return u"%ATTACHMENTCOUNT"_s;
    case AttachmentName:
        return u"%ATTACHMENTNAMES"_s;
    case AttachmentFilenames:
        return u"%ATTACHMENTFILENAMES"_s;
    case AttachmentNamesAndSizes:
        return u"%ATTACHMENTNAMESANDSIZES"_s;
    case Year:
        return u"%YEAR"_s;
    case LastYear:
        return u"%LASTYEAR"_s;
    case NextYear:
        return u"%NEXTYEAR"_s;
    case MonthNumber:
        return u"%MONTHNUMBER"_s; // 1-12
    case DayNumber:
        return u"%DAYNUMBER"_s; // 1-28 to 31
    case CustomDate:
        return u"%CUSTOMDATE"_s; // dd MMM yyyy
    case DayOfMonth:
        return u"%DAYOFMONTH"_s; // 1-31
    case WeekNumber:
        return u"%WEEKNUMBER"_s; // 1-52
    case MonthNameShort:
        return u"%MONTHNAMESHORT"_s; //(Jan-Dec)
    case MonthNameLong:
        return u"%MONTHNAMELONG"_s; //(January-December)
    case DayOfWeek:
        return u"%DAYOFWEEK"_s; //(1-7)
    case DayOfWeekNameShort:
        return u"%DAYOFWEEKNAMESHORT"_s; //(Mon-Sun)
    case DayOfWeekNameLong:
        return u"%DAYOFWEEKNAMELONG"_s; //(Monday-Sunday)
    case YearLastMonth:
        return u"%YEARLASTMONTH"_s; // january 2020 will how 2019-12
    case LastMonthNameLong:
        return u"%LASTMONTHNAMELONG"_s;
    }
    return {};
}

QString MessageComposer::ConvertSnippetVariablesUtil::shortDate()
{
    QLocale locale;
    return locale.toString(QDate::currentDate(), QLocale::ShortFormat);
}

QString MessageComposer::ConvertSnippetVariablesUtil::longDate()
{
    QLocale locale;
    return locale.toString(QDate::currentDate(), QLocale::LongFormat);
}

QString MessageComposer::ConvertSnippetVariablesUtil::customDate()
{
    QLocale locale;
    return locale.toString(QDate::currentDate(), u"dd MMM yyyy"_s);
}

QString MessageComposer::ConvertSnippetVariablesUtil::shortTime()
{
    QLocale locale;
    return locale.toString(QTime::currentTime(), QLocale::ShortFormat);
}

QString MessageComposer::ConvertSnippetVariablesUtil::longTime()
{
    QLocale locale;
    return locale.toString(QTime::currentTime(), QLocale::LongFormat);
}

QString MessageComposer::ConvertSnippetVariablesUtil::insertDayOfWeek()
{
    const QDateTime date = QDateTime::currentDateTime().toLocalTime();
    const QString str = QLocale().dayName(date.date().dayOfWeek(), QLocale::LongFormat);
    return str;
}

QString MessageComposer::ConvertSnippetVariablesUtil::lastYear()
{
    const QDate date = QDate::currentDate();
    return QString::number(date.year() - 1);
}

QString MessageComposer::ConvertSnippetVariablesUtil::nextYear()
{
    const QDate date = QDate::currentDate();
    return QString::number(date.year() + 1);
}

QString MessageComposer::ConvertSnippetVariablesUtil::dayNumber()
{
    const QDate date = QDate::currentDate();
    return QString::number(date.day());
}

QString MessageComposer::ConvertSnippetVariablesUtil::monthNumber()
{
    const QDate date = QDate::currentDate();
    return QString::number(date.month());
}

QString MessageComposer::ConvertSnippetVariablesUtil::dayOfMonth()
{
    const QDate date = QDate::currentDate();
    return QString::number(date.daysInMonth());
}

QString MessageComposer::ConvertSnippetVariablesUtil::weekNumber()
{
    const QDate date = QDate::currentDate();
    return QString::number(date.weekNumber());
}

QString MessageComposer::ConvertSnippetVariablesUtil::monthNameShort()
{
    const QDate date = QDate::currentDate();
    return date.toString(u"MMM"_s);
}

QString MessageComposer::ConvertSnippetVariablesUtil::monthNameLong()
{
    const QDate date = QDate::currentDate();
    return date.toString(u"MMMM"_s);
}

QString MessageComposer::ConvertSnippetVariablesUtil::lastMonthNameLong()
{
    const QDate date = QDate::currentDate().addMonths(-1);
    return date.toString(u"MMMM"_s);
}

QString MessageComposer::ConvertSnippetVariablesUtil::dayOfWeekNameShort()
{
    const QDate date = QDate::currentDate();
    return date.toString(u"ddd"_s);
}

QString MessageComposer::ConvertSnippetVariablesUtil::dayOfWeekNameLong()
{
    const QDate date = QDate::currentDate();
    return date.toString(u"dddd"_s);
}

QString MessageComposer::ConvertSnippetVariablesUtil::yearLastMonth()
{
    const QDate date = QDate::currentDate();
    return date.toString(date.toString(u"yyyy-MMM"_s));
}

QString MessageComposer::ConvertSnippetVariablesUtil::year()
{
    const QDate date = QDate::currentDate();
    return date.toString(QString::number(date.year()));
}

QString MessageComposer::ConvertSnippetVariablesUtil::dayOfWeek()
{
    const QDate date = QDate::currentDate();
    return date.toString(QString::number(date.dayOfWeek()));
}
